==> fetchp-0.0.42.tgz: package/esm/use-fetchp.js <==
import { React } from "./deps-external.js";
import { fetchp, FetchpStatus, } from "./fetchp.js";
const useFetchpBuilder = function useFetchpBuilder(fetchpInstance) {
    // deno-lint-ignore no-explicit-any
    return function useFetchp(method, uri, init) {
        const [data, setData] = React.useState();
        const [status, setStatus] = React.useState(FetchpStatus.IDLE);
        // deno-lint-ignore no-explicit-any
        const [error, setError] = React.useState();
        const [result, setResult] = React.useState();
        const [doFetch, setDoFetch] = React.useState(undefined);
        React.useEffect(() => {
            if (doFetch === undefined) {
                return;
            }
            const fetchData = async function fetchData() {
                // try {
                //   const result = fetchpInstance.request<T>(method, uri, {
                //     ...(init ?? {}),
                //     immediate: true,
                //     statusCallback: (newStatus) => {
                //       setStatus(newStatus);
                //     },
                //     errorCallback: (newError) => setError(newError),
                //     successCallback: (newData) => setData(newData),
                //     // cancelCallback: () => {},
                //   });
                var _a, _b, _c;
                //   setResult(result);
                // } catch (error) {
                //   setError(error);
                //   console.error(error);
                //   setStatus(FetchpStatus.ERROR);
                // }
                setError(undefined);
                setStatus(FetchpStatus.FETCHING);
                try {
                    const finalInit = Object.assign(Object.assign(Object.assign({}, (init !== null && init !== void 0 ? init : {})), ((_a = doFetch[0]) !== null && _a !== void 0 ? _a : {})), { immediate: true });
                    const result = fetchpInstance.request(method, uri, finalInit);
                    setResult(result);
                    (_b = doFetch[1]) === null || _b === void 0 ? void 0 : _b.call(doFetch, result);
                    const localData = await result.data;
                    setData(localData);
                    if (result.abortController.signal.aborted) {
                        setStatus(FetchpStatus.CANCELED);
                    }
                    else {
                        setStatus(FetchpStatus.SUCCESS);
                    }
                }
                catch (error) {
                    setError(error);
                    (_c = doFetch[2]) === null || _c === void 0 ? void 0 : _c.call(doFetch, error);
                    console.error(error);
                    setStatus(FetchpStatus.ERROR);
                }
            };
            fetchData();
        }, [doFetch]);
        return {
            doFetch: (init) => new Promise((resolve, reject) => setDoFetch([init, resolve, reject])),
            data,
            status,
            isIdle: status === FetchpStatus.IDLE,
            isFetching: status === FetchpStatus.FETCHING,
            isLoading: status === FetchpStatus.LOADING,
            isError: status === FetchpStatus.ERROR,
            isCanceled: status === FetchpStatus.CANCELED,
            isSuccess: status === FetchpStatus.SUCCESS,
            error,
            result,
        };
    };
};
const useFetchp = useFetchpBuilder(fetchp);
export { FetchpStatus, useFetchp, useFetchp as default, useFetchpBuilder };

==> fetchp-0.0.43.tgz: package/esm/use-fetchp.js <==
import { React } from "./deps-external.js";
import { fetchp, FetchpStatus, } from "./fetchp.js";
const useFetchpBuilder = (fetchpInstance) => {
    // deno-lint-ignore no-explicit-any
    const useFetchp = (method, uri, init) => {
        const [data, setData] = React.useState();
        const [status, setStatus] = React.useState(FetchpStatus.IDLE);
        // deno-lint-ignore no-explicit-any
        const [error, setError] = React.useState();
        const [result, setResult] = React.useState();
        const [doFetch, setDoFetch] = React.useState(undefined);
        React.useEffect(() => {
            if (doFetch === undefined) {
                return;
            }
            const fetchData = async () => {
                // try {
                //   const result = fetchpInstance.request<T>(method, uri, {
                //     ...(init ?? {}),
                //     immediate: true,
                //     statusCallback: (newStatus) => {
                //       setStatus(newStatus);
                //     },
                //     errorCallback: (newError) => setError(newError),
                //     successCallback: (newData) => setData(newData),
                //     // cancelCallback: () => {},
                //   });
                var _a, _b, _c;
                //   setResult(result);
                // } catch (error) {
                //   setError(error);
                //   console.error(error);
                //   setStatus(FetchpStatus.ERROR);
                // }
                setError(undefined);
                setStatus(FetchpStatus.FETCHING);
                try {
                    const finalInit = Object.assign(Object.assign(Object.assign({}, (init !== null && init !== void 0 ? init : {})), ((_a = doFetch[0]) !== null && _a !== void 0 ? _a : {})), { immediate: true });
                    const result = fetchpInstance.request(method, uri, finalInit);
                    setResult(result);
                    (_b = doFetch[1]) === null || _b === void 0 ? void 0 : _b.call(doFetch, result);
                    const localData = await result.data;
                    setData(localData);
                    if (result.abortController.signal.aborted) {
                        setStatus(FetchpStatus.CANCELED);
                    }
                    else {
                        setStatus(FetchpStatus.SUCCESS);
                    }
                }
                catch (error) {
                    setError(error);
                    (_c = doFetch[2]) === null || _c === void 0 ? void 0 : _c.call(doFetch, error);
                    console.error(error);
                    setStatus(FetchpStatus.ERROR);
                }
            };
            fetchData();
        }, [doFetch]);
        return {
            doFetch: (init) => new Promise((resolve, reject) => setDoFetch([init, resolve, reject])),
            data,
            status,
            isIdle: status === FetchpStatus.IDLE,
            isFetching: status === FetchpStatus.FETCHING,
            isLoading: status === FetchpStatus.LOADING,
            isError: status === FetchpStatus.ERROR,
            isCanceled: status === FetchpStatus.CANCELED,
            isSuccess: status === FetchpStatus.SUCCESS,
            error,
            result,
        };
    };
    return useFetchp;
};
const useFetchp = useFetchpBuilder(fetchp);
export { FetchpStatus, useFetchp, useFetchp as default, useFetchpBuilder };
